@@ -72,11 +72,17 @@ def parse_miscale(self, data, source_mac, rssi):
         "stabilized": 0 if is_stabilized == 0 else 1
     }
 
-    if is_stabilized and not weight_removed:
-        result.update({"weight": weight})
-
-    if has_impedance:
-        result.update({"impedance": impedance})
+    if device_type == "Mi Scale V1":
+        if is_stabilized and not weight_removed:
+            result.update({"weight": weight})
+    elif device_type == "Mi Scale V2":
+        if is_stabilized and (weight_removed == 0):
+            result.update({"stabilized weight": weight})
+            if has_impedance:
+                result.update({"weight": weight})
+                result.update({"impedance": impedance})
+    else:
+        pass
 
     firmware = device_type
     miscale_mac = source_mac
