@@ -1,4 +1,4 @@
-# Parser for Xiaomi MiBeacon BLE advertisements
+"""Parser for Xiaomi MiBeacon BLE advertisements"""
 import logging
 import math
 import struct
@@ -98,16 +98,16 @@ BLE_LOCK_ERROR = {
 }
 
 BLE_LOCK_ACTION = {
-    0b0000: [0, "unlock outside the door"],
-    0b0001: [1, "lock"],
-    0b0010: [1, "turn on anti-lock"],
-    0b0011: [0, "turn off anti-lock"],
-    0b0100: [0, "unlock inside the door"],
-    0b0101: [1, "lock inside the door"],
-    0b0110: [1, "turn on child lock"],
-    0b0111: [0, "turn off child lock"],
-    0b1000: [1, "lock outside the door"],
-    0b1111: [0, "abnormal"],
+    0b0000: [1, "lock", "unlock outside the door"],
+    0b0001: [0, "lock", "lock"],
+    0b0010: [0, "antilock", "turn on anti-lock"],
+    0b0011: [1, "antilock", "turn off anti-lock"],
+    0b0100: [1, "lock", "unlock inside the door"],
+    0b0101: [0, "lock", "lock inside the door"],
+    0b0110: [0, "childlock", "turn on child lock"],
+    0b0111: [1, "childlock", "turn off child lock"],
+    0b1000: [0, "lock", "lock outside the door"],
+    0b1111: [1, "lock", "abnormal"],
 }
 
 BLE_LOCK_METHOD = {
@@ -130,12 +130,12 @@ BLE_LOCK_METHOD = {
 # Advertisement conversion of measurement data
 # https://iot.mi.com/new/doc/embedded-development/ble/object-definition
 def obj0003(xobj):
-    # Motion
+    """Motion"""
     return {"motion": xobj[0], "motion timer": xobj[0]}
 
 
 def obj0006(xobj):
-    # Fingerprint
+    """Fingerprint"""
     if len(xobj) == 5:
         key_id = xobj[0:4]
         match_byte = xobj[4]
@@ -173,16 +173,42 @@ def obj0006(xobj):
         return {}
 
 
+def obj0007(xobj):
+    """Door"""
+    door_byte = xobj[0]
+    if door_byte == 0x00:
+        action = "open the door"
+        door = 1
+    elif door_byte == 0x01:
+        action = "close the door"
+        door = 0
+    elif door_byte == 0x02:
+        action = "timeout, not closed"
+        door = 1
+    elif door_byte == 0x03:
+        action = "knock on the door"
+        door = 0
+    elif door_byte == 0x04:
+        action = "pry the door"
+        door = 1
+    elif door_byte == 0x05:
+        action = "door stuck"
+        door = 0
+    else:
+        return {}
+    return {"door": door, "door action": action}
+
+
 def obj0010(xobj):
-    # Toothbrush
+    """Toothbrush"""
     if xobj[0] == 0:
         return {'toothbrush': 1, 'counter': xobj[1]}
     else:
         return {'toothbrush': 0, 'score': xobj[1]}
 
 
-def obj000b(xobj):
-    # Lock
+def obj000b(xobj, device_type):
+    """Lock"""
     if len(xobj) == 9:
         action = xobj[0] & 0x0F
         method = xobj[0] >> 4
@@ -202,11 +228,16 @@ def obj000b(xobj):
             return {}
 
         lock = BLE_LOCK_ACTION[action][0]
-        action = BLE_LOCK_ACTION[action][1]
+        # Decouple lock by type on some devices
+        lock_type = "lock"
+        if device_type == "ZNMS17LM":
+            lock_type = BLE_LOCK_ACTION[action][1]
+        action = BLE_LOCK_ACTION[action][2]
         method = BLE_LOCK_METHOD[method]
 
         return {
-            "lock": lock,
+            lock_type: lock,
+            "locktype": lock_type,
             "action": action,
             "method": method,
             "error": error,
@@ -218,7 +249,7 @@ def obj000b(xobj):
 
 
 def obj000f(xobj, device_type):
-    # Moving with light
+    """Moving with light"""
     if len(xobj) == 3:
         (value,) = LIGHT_STRUCT.unpack(xobj + b'\x00')
 
@@ -236,6 +267,7 @@ def obj000f(xobj, device_type):
 
 
 def obj1001(xobj, device_type):
+    """button"""
     if len(xobj) == 3:
         (button_type, value, press) = BUTTON_STRUCT.unpack(xobj)
 
@@ -250,6 +282,7 @@ def obj1001(xobj, device_type):
         three_btn_switch_left = None
         three_btn_switch_middle = None
         three_btn_switch_right = None
+        cube_direction = None
         remote_binary = None
 
         if button_type == 0:
@@ -260,6 +293,7 @@ def obj1001(xobj, device_type):
             one_btn_switch = "toggle"
             two_btn_switch_left = "toggle"
             three_btn_switch_left = "toggle"
+            cube_direction = "right"
             remote_binary = 1
         elif button_type == 1:
             remote_command = "off"
@@ -268,6 +302,7 @@ def obj1001(xobj, device_type):
             bathroom_remote_command = "air exchange"
             two_btn_switch_right = "toggle"
             three_btn_switch_middle = "toggle"
+            cube_direction = "left"
             remote_binary = 0
         elif button_type == 2:
             remote_command = "sun"
@@ -315,17 +350,14 @@ def obj1001(xobj, device_type):
         # press type and dimmer
         button_press_type = "no press"
         btn_switch_press_type = "no press"
-        cube_direction = None
         dimmer = None
 
         if press == 0:
             button_press_type = "single press"
             btn_switch_press_type = "single press"
-            cube_direction = "right"
         elif press == 1:
             button_press_type = "double press"
             btn_switch_press_type = "long press"
-            cube_direction = "left"
         elif press == 2:
             button_press_type = "long press"
             btn_switch_press_type = "double press"
@@ -407,7 +439,7 @@ def obj1001(xobj, device_type):
 
 
 def obj1004(xobj):
-    # Temperature
+    """Temperature"""
     if len(xobj) == 2:
         (temp,) = T_STRUCT.unpack(xobj)
         return {"temperature": temp / 10}
@@ -416,11 +448,12 @@ def obj1004(xobj):
 
 
 def obj1005(xobj):
+    """Switch and Temperature"""
     return {"switch": xobj[0], "temperature": xobj[1]}
 
 
 def obj1006(xobj):
-    # Humidity
+    """Humidity"""
     if len(xobj) == 2:
         (humi,) = H_STRUCT.unpack(xobj)
         return {"humidity": humi / 10}
@@ -429,7 +462,7 @@ def obj1006(xobj):
 
 
 def obj1007(xobj):
-    # Illuminance
+    """Illuminance"""
     if len(xobj) == 3:
         (illum,) = ILL_STRUCT.unpack(xobj + b'\x00')
         return {"illuminance": illum, "light": 1 if illum == 100 else 0}
@@ -438,12 +471,12 @@ def obj1007(xobj):
 
 
 def obj1008(xobj):
-    # Moisture
+    """Moisture"""
     return {"moisture": xobj[0]}
 
 
 def obj1009(xobj):
-    # Conductivity
+    """Conductivity"""
     if len(xobj) == 2:
         (cond,) = CND_STRUCT.unpack(xobj)
         return {"conductivity": cond}
@@ -452,7 +485,7 @@ def obj1009(xobj):
 
 
 def obj1010(xobj):
-    # Formaldehyde
+    """Formaldehyde"""
     if len(xobj) == 2:
         (fmdh,) = FMDH_STRUCT.unpack(xobj)
         return {"formaldehyde": fmdh / 100}
@@ -461,27 +494,27 @@ def obj1010(xobj):
 
 
 def obj1012(xobj):
-    # Switch
+    """Switch"""
     return {"switch": xobj[0]}
 
 
 def obj1013(xobj):
-    # Consumable (in percent)
+    """Consumable (in percent)"""
     return {"consumable": xobj[0]}
 
 
 def obj1014(xobj):
-    # Moisture
+    """Moisture"""
     return {"moisture": xobj[0]}
 
 
 def obj1015(xobj):
-    # Smoke
+    """Smoke"""
     return {"smoke detector": xobj[0]}
 
 
 def obj1017(xobj):
-    # Motion
+    """Motion"""
     if len(xobj) == 4:
         (motion,) = M_STRUCT.unpack(xobj)
         # seconds since last motion detected message (not used, we use motion timer in obj000f)
@@ -492,12 +525,12 @@ def obj1017(xobj):
 
 
 def obj1018(xobj):
-    # Light intensity
+    """Light intensity"""
     return {"light": xobj[0]}
 
 
 def obj1019(xobj):
-    # Door
+    """Door/Window sensor"""
     open_obj = xobj[0]
     if open_obj == 0:
         opening = 1
@@ -518,14 +551,14 @@ def obj1019(xobj):
 
 
 def obj100a(xobj):
-    # Battery
+    """Battery"""
     batt = xobj[0]
     volt = 2.2 + (3.1 - 2.2) * (batt / 100)
     return {"battery": batt, "voltage": volt}
 
 
 def obj100d(xobj):
-    # Temperature and humidity
+    """Temperature and humidity"""
     if len(xobj) == 4:
         (temp, humi) = TH_STRUCT.unpack(xobj)
         return {"temperature": temp / 10, "humidity": humi / 10}
@@ -534,7 +567,7 @@ def obj100d(xobj):
 
 
 def obj2000(xobj):
-    # Body temperature
+    """Body temperature"""
     if len(xobj) == 5:
         (temp1, temp2, bat) = TTB_STRUCT.unpack(xobj)
         # Body temperature is calculated from the two measured temperatures.
@@ -552,12 +585,13 @@ def obj2000(xobj):
 # The following data objects are device specific. For now only added for XMWSDJ04MMC
 # https://miot-spec.org/miot-spec-v2/instances?status=all
 def obj4803(xobj):
-    # Battery
+    """Battery"""
     batt = xobj[0]
     return {"battery": batt}
 
 
 def obj4c01(xobj):
+    """Temperature"""
     if len(xobj) == 4:
         temp = FLOAT_STRUCT.unpack(xobj)[0]
         return {"temperature": temp}
@@ -566,6 +600,7 @@ def obj4c01(xobj):
 
 
 def obj4c08(xobj):
+    """Humidity"""
     if len(xobj) == 4:
         humi = FLOAT_STRUCT.unpack(xobj)[0]
         return {"humidity": humi}
@@ -578,6 +613,7 @@ def obj4c08(xobj):
 xiaomi_dataobject_dict = {
     0x0003: obj0003,
     0x0006: obj0006,
+    0x0007: obj0007,
     0x0010: obj0010,
     0x000B: obj000b,
     0x000F: obj000f,
@@ -606,6 +642,7 @@ xiaomi_dataobject_dict = {
 
 
 def parse_xiaomi(self, data, source_mac, rssi):
+    """Parser for Xiaomi sensors"""
     # check for adstruc length
     i = 9  # till Frame Counter
     msg_length = len(data)
@@ -697,7 +734,7 @@ def parse_xiaomi(self, data, source_mac, rssi):
         # start with empty first packet
         prev_packet = None
 
-    if device_type in ["LYWSD03MMC", "CGG1", "MHO-C401"]:
+    if device_type in ["LYWSD03MMC", "CGG1", "MHO-C401", "CGDK2"]:
         # Check for adv priority and packet_id for devices that can also send in ATC format
         adv_priority = 19
         try:
@@ -791,14 +828,14 @@ def parse_xiaomi(self, data, source_mac, rssi):
             if payload_length < next_start:
                 _LOGGER.debug("Invalid payload data length, payload: %s", payload.hex())
                 break
-            dobject  = payload[payload_start + 3:next_start]
+            dobject = payload[payload_start + 3:next_start]
             if obj_length != 0:
                 resfunc = xiaomi_dataobject_dict.get(obj_typecode, None)
                 if resfunc:
-                    if hex(obj_typecode) in ["0x1001", "0xf"]:
-                        result.update(resfunc(dobject , device_type))
+                    if hex(obj_typecode) in ["0x1001", "0xf", "0xb"]:
+                        result.update(resfunc(dobject, device_type))
                     else:
-                        result.update(resfunc(dobject ))
+                        result.update(resfunc(dobject))
                 else:
                     if self.report_unknown == "Xiaomi":
                         _LOGGER.info("%s, UNKNOWN dataobject in payload! Adv: %s", sinfo, data.hex())
@@ -808,6 +845,7 @@ def parse_xiaomi(self, data, source_mac, rssi):
 
 
 def decrypt_mibeacon_v4_v5(self, data, i, xiaomi_mac):
+    """decrypt MiBeacon v4/v5 encrypted advertisements"""
     # check for minimum length of encrypted advertisement
     if len(data) < i + 9:
         _LOGGER.debug("Invalid data length (for decryption), adv: %s", data.hex())
@@ -847,6 +885,7 @@ def decrypt_mibeacon_v4_v5(self, data, i, xiaomi_mac):
 
 
 def decrypt_mibeacon_legacy(self, data, i, xiaomi_mac):
+    """decrypt MiBeacon v2/v3 encrypted advertisements"""
     # check for minimum length of encrypted advertisement
     if len(data) < i + 7:
         _LOGGER.debug("Invalid data length (for decryption), adv: %s", data.hex())
